[dovecot-cvs] dovecot/src/lib-storage mail-storage.c, 1.41, 1.42 mail-storage.h, 1.97, 1.98

cras at dovecot.org cras at dovecot.org
Sun Aug 7 14:41:30 EEST 2005


Update of /var/lib/cvs/dovecot/src/lib-storage
In directory talvi:/tmp/cvs-serv27981/src/lib-storage

Modified Files:
	mail-storage.c mail-storage.h 
Log Message:
s/occured/occurred/



Index: mail-storage.c
===================================================================
RCS file: /var/lib/cvs/dovecot/src/lib-storage/mail-storage.c,v
retrieving revision 1.41
retrieving revision 1.42
diff -u -d -r1.41 -r1.42
--- mail-storage.c	29 Jul 2005 08:43:04 -0000	1.41
+++ mail-storage.c	7 Aug 2005 11:41:26 -0000	1.42
@@ -11,7 +11,7 @@
 
 /* Message to show to users when critical error occurs */
 #define CRITICAL_MSG \
-	"Internal error occured. Refer to server log for more information."
+	"Internal error occurred. Refer to server log for more information."
 #define CRITICAL_MSG_STAMP CRITICAL_MSG " [%Y-%m-%d %H:%M:%S]"
 
 unsigned int mail_storage_module_id = 0;

Index: mail-storage.h
===================================================================
RCS file: /var/lib/cvs/dovecot/src/lib-storage/mail-storage.h,v
retrieving revision 1.97
retrieving revision 1.98
diff -u -d -r1.97 -r1.98
--- mail-storage.h	29 Jul 2005 08:43:04 -0000	1.97
+++ mail-storage.h	7 Aug 2005 11:41:26 -0000	1.98
@@ -268,7 +268,7 @@
 struct mailbox_list *
 mail_storage_mailbox_list_next(struct mailbox_list_context *ctx);
 /* Deinitialize mailbox list request. Returns FALSE if some error
-   occured while listing. */
+   occurred while listing. */
 int mail_storage_mailbox_list_deinit(struct mailbox_list_context *ctx);
 
 /* Subscribe/unsubscribe mailbox. There should be no error when
@@ -282,7 +282,7 @@
 					 const char *name,
 					 enum mailbox_name_status *status);
 
 /* Returns the error message of last occured error. */
 const char *mail_storage_get_last_error(struct mail_storage *storage,
 					int *syntax_error_r,
 					int *temporary_error_r);
@@ -296,7 +296,7 @@
 struct mailbox *mailbox_open(struct mail_storage *storage, const char *name,
 			     struct istream *input,
 			     enum mailbox_open_flags flags);
 /* Close the box. Returns FALSE if some cleanup errors occured, but
    the mailbox was closed anyway. */
 int mailbox_close(struct mailbox *box);
 
@@ -416,18 +416,18 @@
 int mail_set_seq(struct mail *mail, uint32_t seq);
 
 /* Get the time message was received (IMAP INTERNALDATE).
-   Returns (time_t)-1 if error occured. */
+   Returns (time_t)-1 if error occurred. */
 time_t mail_get_received_date(struct mail *mail);
 /* Get the Date-header in mail. Timezone is in minutes.
-   Returns (time_t)-1 if error occured, 0 if field wasn't found or
+   Returns (time_t)-1 if error occurred, 0 if field wasn't found or
    couldn't be parsed. */
 time_t mail_get_date(struct mail *mail, int *timezone);
 
 /* Get the full virtual size of mail (IMAP RFC822.SIZE).
-   Returns (uoff_t)-1 if error occured */
+   Returns (uoff_t)-1 if error occurred */
 uoff_t mail_get_virtual_size(struct mail *mail);
 /* Get the full physical size of mail.
-   Returns (uoff_t)-1 if error occured */
+   Returns (uoff_t)-1 if error occurred */
 uoff_t mail_get_physical_size(struct mail *mail);
 
 /* Get value for single header field */
@@ -282,7 +282,7 @@
 					 enum mailbox_name_status *status);
 
-/* Returns the error message of last occured error. */
+/* Returns the error message of last occurred error. */
 const char *mail_storage_get_last_error(struct mail_storage *storage,
 					int *syntax_error_r,
@@ -296,7 +296,7 @@
 			     struct istream *input,
 			     enum mailbox_open_flags flags);
-/* Close the box. Returns FALSE if some cleanup errors occured, but
+/* Close the box. Returns FALSE if some cleanup errors occurred, but
    the mailbox was closed anyway. */
 int mailbox_close(struct mailbox *box);



More information about the dovecot-cvs mailing list